==> odps-jdbc-3.3.0-sources.jar: com/aliyun/odps/jdbc/utils/transformer/to/odps/ToOdpsDatetimeTransformer.java <==
/*
 *  Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements.  See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership.  The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License.
 *
 */

package com.aliyun.odps.jdbc.utils.transformer.to.odps;

import java.sql.SQLException;
import java.sql.Time;
import java.sql.Timestamp;
import java.util.Date;

public class ToOdpsDatetimeTransformer extends AbstractToOdpsTransformer {

  @Override
  public Object transform(Object o, String charset) throws SQLException {
    if (o == null) {
      return null;
    }

    if (Timestamp.class.isInstance(o)
        || java.sql.Date.class.isInstance(o)
        || Time.class.isInstance(o)) {
      return new Date(((Date) o).getTime());
    } else if (Date.class.isInstance(o)) {
      return o;
    } else {
      String errorMsg = getInvalidTransformationErrorMsg(o.getClass(), Date.class);
      throw new SQLException(errorMsg);
    }
  }
}

==> odps-jdbc-3.3.6-sources.jar: com/aliyun/odps/jdbc/utils/transformer/to/odps/ToOdpsDatetimeTransformer.java <==
/*
 *  Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements.  See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership.  The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License.
 *
 */

package com.aliyun.odps.jdbc.utils.transformer.to.odps;

import java.sql.SQLException;
import java.sql.Time;
import java.sql.Timestamp;
import java.time.ZoneId;
import java.util.Date;

public class ToOdpsDatetimeTransformer extends AbstractToOdpsTransformer {

  @Override
  public Object transform(Object o, String charset) throws SQLException {
    if (o == null) {
      return null;
    }

    if (Timestamp.class.isInstance(o)
        || java.sql.Date.class.isInstance(o)
        || Time.class.isInstance(o)) {
      return new java.util.Date(((Date) o).getTime()).toInstant().atZone(ZoneId.systemDefault());
    } else if (Date.class.isInstance(o)) {
      return ((java.util.Date) o).toInstant().atZone(ZoneId.systemDefault());
    } else {
      String errorMsg = getInvalidTransformationErrorMsg(o.getClass(), Date.class);
      throw new SQLException(errorMsg);
    }
  }
}
